==> haskell-hls-cabal-fmt-plugin-0.1.0.0-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-fmt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-cabal-fmt-plugin
version:              0.1.0.0
visibility:           public
id:                   hls-cabal-fmt-plugin-0.1.0.0-BCwUUTD6pkJGyAYgPWjIFJ
key:                  hls-cabal-fmt-plugin-0.1.0.0-BCwUUTD6pkJGyAYgPWjIFJ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           jana.chadt@nets.at
author:               The Haskell IDE Team
synopsis:             Integration with the cabal-fmt code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2cc908db0bcfa9252f94fb3ed6fcdc7d
exposed:              True
exposed-modules:      Ide.Plugin.CabalFmt
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-cabal-fmt-plugin-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-cabal-fmt-plugin-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-fmt-plugin
hs-libraries:         HShls-cabal-fmt-plugin-0.1.0.0-BCwUUTD6pkJGyAYgPWjIFJ
depends:
    base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
    ghcide-1.10.0.0-8N69zrdFqmeLL7sPaHEIQq
    hls-plugin-api-1.6.0.0-Ca7hbYl2UGtL2lMuiElAIW
    lens-5.2.3-LJCKq2CVV0OBzhsqfjAjcB
    lsp-types-1.6.0.0-463dpHwu7XHCh3whjfPg50 process-1.6.16.0
    text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-fmt-plugin/html/hls-cabal-fmt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-fmt-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-cabal-fmt-plugin-0.1.0.0-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-fmt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-cabal-fmt-plugin
version:              0.1.0.0
visibility:           public
id:                   hls-cabal-fmt-plugin-0.1.0.0-GDGPgeIbYQj3xVbtFfkNYN
key:                  hls-cabal-fmt-plugin-0.1.0.0-GDGPgeIbYQj3xVbtFfkNYN
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           jana.chadt@nets.at
author:               The Haskell IDE Team
synopsis:             Integration with the cabal-fmt code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  a84ff6e63683aba3594142f713d3886f
exposed:              True
exposed-modules:      Ide.Plugin.CabalFmt
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-cabal-fmt-plugin-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-cabal-fmt-plugin-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-fmt-plugin
hs-libraries:         HShls-cabal-fmt-plugin-0.1.0.0-GDGPgeIbYQj3xVbtFfkNYN
depends:
    base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
    ghcide-1.10.0.0-HHQ8G8WsjSJ2AEMQGOwX6
    hls-plugin-api-1.6.0.0-J7scbURco0w3rSkQkePbC4
    lens-5.2.3-Ip76jddesOj5vmVbK7jYXC
    lsp-types-1.6.0.0-2PAEzESuvtVD0aUlvMjlGC process-1.6.16.0
    text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-fmt-plugin/html/hls-cabal-fmt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-fmt-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
